pub struct PlatformSettings;Expand description
Platform-specific settings and information.
Implementations
Sourceimpl PlatformSettings
impl PlatformSettings
Sourcepub fn get_config_dir_path() -> &'static Path
pub fn get_config_dir_path() -> &'static Path
Returns the path to the default Datadog Agent configuration directory.
Sourcepub fn get_config_file_path() -> PathBuf
pub fn get_config_file_path() -> PathBuf
Returns the path to the default Datadog Agent configuration file.
Sourcepub fn get_auth_token_path() -> PathBuf
pub fn get_auth_token_path() -> PathBuf
Returns the path to the default Datadog Agent authentication token.
Sourcepub fn get_ipc_cert_filename() -> &'static Path
pub fn get_ipc_cert_filename() -> &'static Path
Returns the filename of the IPC certificate file.
Sourcepub fn get_default_log_file_path() -> PathBuf
pub fn get_default_log_file_path() -> PathBuf
Returns the default log file path for the Agent Data Plane.
Sourcepub fn get_default_dogstatsd_log_file_path() -> PathBuf
pub fn get_default_dogstatsd_log_file_path() -> PathBuf
Returns the default DogStatsD debug log file path.
Sourcepub const fn get_default_syslog_uri() -> &'static str
pub const fn get_default_syslog_uri() -> &'static str
Returns the default local syslog URI used by the Datadog Agent on this platform.
Sourcepub const fn get_env_var_prefix() -> &'static str
pub const fn get_env_var_prefix() -> &'static str
Returns the prefix for all environment variables used by the Datadog Agent.